@@ -5,7 +5,9 @@ use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Dbc::Schema;
 use Log::Log4perl;
 Log::Log4perl->init("log.conf");
-use Forms::Langues_dbc;
+use Forms::Langues;
+use DataAccess::Dbc::Service;
+#use Devel::Cycle;
 
 sub get_schema {
     my $file = shift;
@@ -20,11 +22,14 @@ sub get_schema {
 }
 
 sub load_main_w {
-
-    my $app = Forms::Langues_dbc->new(
-        { xrcfolder => "./xrc", schema => get_schema("./data/ex1_1") } );
+  my $data = DataAccess::Dbc::Service->new({schema => get_schema("./data/ex1_1") });  
+    my $app = Forms::Langues->new(
+        { xrcfolder => "./xrc", data_broker => $data } );
     $app->GetTopWindow->Move( 10, 10 );
     $app->MainLoop;
+    #find_cycle($app);
+    #print "Weakened\n";
+    #find_weakened_cycle($app);
 
 }
 
