@@ -693,9 +693,9 @@ sub new {
         my $col = 0;
         for my $f ( @{ $self->{fields} } ) {
             my $fname = $f->{name};
-            my $v     = $self->{dman}->get_field($fname);
-
-#$self->{log}->debug(" row: ", $i , " $fname: ", (defined $v ? $v : " undef"));
+            $self->{log}->debug(" row: ", $i , " name : ", $fname); #: ", (defined $v ? $v : " undef"));
+            #RdbDataManager crash when looking for a calculated field that does not exists in the table
+            my $v     = $self->{dman}->get_field($fname) unless $f->{renderer_function};
             $$self{array}->[$i][ $col++ ] = $v;
         }
 
