@@ -75,7 +75,7 @@ my %getter = (
 
 private log => my %log;
 private event => my %events;
-private states => my %states;
+# private states => my %states;
 private widgets => my %widgets;
 private fields_with_event => my %ecols;
 private is_with_event => my %is_ecols;
@@ -841,6 +841,14 @@ sub _set_record_status_label {
     }
 }
 
+#return an hashref of line number => first column value
+sub get_combo_ids{
+    my $self = shift;
+    my $id = id $self;
+    my $combo_id = shift;
+    return $datawidgets_value{ $id }->{$combo_id};
+}
+
 1;
 
 __END__
@@ -1139,6 +1147,10 @@ C<fields> an array reference holdings the names of fields in the combo (this par
 
 This method can also be called as a class method, when the underlying form is not bound to any table. You need to pass the builder object (described above) as a supplemental parameter.
 
+=head2 C<get_combo_ids( $combo_name ); >
+
+Return an hash ref of { line number =>  first column value } for combo_name. First line is 0.
+
 =head2 C<update();> See L<Gtk2::Ex::DbLinker::AbForm/update()>
 
 =head2 C<get_data_manager();>  See L<Gtk2::Ex::DbLinker::AbForm/get_data_manager()>
